@@ -16,6 +16,7 @@
 #'
 #' @importFrom utils download.file read.csv unzip
 #' @importFrom curl has_internet
+#' @importFrom httr GET content add_headers
 #'
 #' @export
 #' @examples \dontrun{
@@ -34,8 +35,6 @@ bhavtoday = function(se = 'NSE')
     return(invisible(NULL))
   }
 
-  baseurl = "https://archives.nseindia.com/content/historical/EQUITIES/"
-  end = ".csv.zip"
   month = format(Sys.time(), "%m")
   mt1 = month
   month = as.integer(month)
@@ -44,22 +43,25 @@ bhavtoday = function(se = 'NSE')
   year = format(Sys.time(), "%Y")
   date = format(Sys.time(), "%d")
 
-  bhavurl = paste0(baseurl, year, "/", month, "/cm", date, month, year, "bhav", end)
-  name = paste0(date, month, year)
-  zipname = paste0("cm", date, month, year, "bhav", ".csv")
-
-  nsebhav = function(x){
-  temp = tempfile()
-  download.file(bhavurl, temp)
-  df = read.csv(unz(temp, filename = zipname))
-  unlink(temp)
-  return(df)
+  nsebhav = function(){
+    nseurl = paste0("https://nsearchives.nseindia.com/products/content/sec_bhavdata_full_", date, mt1, year, ".csv")
+    #url <- "https://nsearchives.nseindia.com/products/content/sec_bhavdata_full_02012019.csv"
+    UA <- paste('Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:98.0)',
+                'Gecko/20100101 Firefox/98.0')
+    res <- GET(nseurl, add_headers(`User-Agent` = UA, Connection = 'keep-alive'))
+    df1 = content(res)
+    df1 = df1[,c(-10,-14, -15)]
+    df1 = df1[,c(1,2,5,6,7,9,8,4,10,11,3,12)]
+    df1$ISIN = ''
+    df1$X = ''
+    colnames(df1) <- c("SYMBOL","SERIES","OPEN","HIGH","LOW","CLOSE","LAST","PREVCLOSE" ,
+                       "TOTTRDQTY","TOTTRDVAL","TIMESTAMP","TOTALTRADES" ,"ISIN","X")
+    return(df1)
   }
 
   dy = date
   yr1 = substr(year, start = 3, stop = 4)
 
-
   bseurl = paste0('https://www.bseindia.com/download/BhavCopy/Equity/EQ_ISINCODE_', dy, mt1, yr1, '.zip')
   bsezip = paste0('EQ_ISINCODE_', dy, mt1, yr1, '.CSV')
 
@@ -73,8 +75,7 @@ bhavtoday = function(se = 'NSE')
   }
 
   if(se == 'NSE'){
-    df = tryCatch(nsebhav(), error=function(e) conditionMessage(w),
-                  warning = function(w) conditionMessage(w))
+    df = tryCatch(nsebhav(), error=function(e) nsebhav(), warning = function(w) conditionMessage(w))
   }else if(se == 'BSE') df = tryCatch(bsebhav(), error = function(e) conditionMessage(e),
                                       warning = function(w) conditionMessage(w))
 
